Learn R Programming

c2c (version 0.1.0)

percentage_agreement: Calculate overall percentage agreement

Description

Used to calculate overall percentage agreement for a confusion matrix - the confusion matrix must have equal dimensions and the diagonal must represent 'matching' class pairs (percentage agreement does not make sense otherwise)

Usage

percentage_agreement(conf_mat)

Arguments

conf_mat

A confusion matrix from get_conf_mat or otherwise (ideally a matrix, although data frames will probably work)

Value

A scaler, percentage agreement (sometime referred to as overall accuracy)