Used to calculate overall percentage agreement for a confusion matrix - the confusion matrix must have equal dimensions and the diagonal must represent 'matching' class pairs (percentage agreement does not make sense otherwise)
percentage_agreement(conf_mat)A confusion matrix from get_conf_mat or otherwise (ideally a matrix, although data frames will probably work)
A scaler, percentage agreement (sometime referred to as overall accuracy)